@@ -5,7 +5,7 @@ assert_array_almost_equal
 import tempfile, unittest, os, random
 import numpy as np
 
-file_name = tempfile.mktemp(".nc")
+file_name = tempfile.NamedTemporaryFile(suffix='.nc', delete=False).name
 xdim=9; ydim=10; zdim=11
 #seed(9) # fix seed
 data = randint(0,10,size=(xdim,ydim,zdim)).astype('u1')
@@ -94,6 +94,10 @@ class VariablesTestCase(unittest.TestCase):
         v[...] = 10
         assert_array_equal(v[...], 10)
         assert_equal(v.shape, v[...].shape)
+        # issue #785: always return masked array
+        #assert(type(v[...]) == np.ndarray)
+        assert(type(v[...]) == np.ma.core.MaskedArray)
+        f.set_auto_mask(False)
         assert(type(v[...]) == np.ndarray)
         f.close()
 
@@ -125,7 +129,7 @@ class VariablesTestCase(unittest.TestCase):
         nlons = 12; lon = f.createDimension('lon',nlons)
         nlevs = 1; lev = f.createDimension('lev',nlevs)
         time = f.createDimension('time',None)
-        var = f.createVariable('var',np.float,('time','lev','lat','lon'))
+        var = f.createVariable('var',np.float_,('time','lev','lat','lon'))
         a = np.random.uniform(size=(10,nlevs,nlats,nlons))
         var[0:10] = a
         f.close()
@@ -164,7 +168,7 @@ class VariablesTestCase(unittest.TestCase):
         nlats = 11; lat = f.createDimension('lat',nlats)
         nlons = 20; lon = f.createDimension('lon',nlons)
         time = f.createDimension('time',None)
-        var = f.createVariable('var',np.float,('time','lat','lon'))
+        var = f.createVariable('var',np.float_,('time','lat','lon'))
         a = np.random.uniform(size=(3,nlats,nlons))
         var[[True,True,False,False,False,True]] = a
         var[0,2.0,"-1"] = 0 # issue 312
@@ -181,5 +185,82 @@ class VariablesTestCase(unittest.TestCase):
         assert_array_almost_equal(cc,a[-1,3:,:6])
         f.close()
 
+    def test_retain_single_dims(self):
+        f = Dataset(self.file, 'r')
+        v = f.variables['data']
+        keys = ((0, 1, 2, 3, 4, 5, 6, 7, 8), (5,), (4,))
+        shape = (9, 1, 1)
+        data = v[keys]
+        assert_equal(data.shape, shape)
+        keys = ((0, 1, 2, 3, 4, 5, 6, 7, 8), 5, 4,)
+        shape = (9,)
+        data = v[keys]
+        assert_equal(data.shape, shape)
+        f.close()
+
+    def test_issue743(self):
+        nc = Dataset(self.file,'w',format='NETCDF3_CLASSIC')
+        td = nc.createDimension('t',None)
+        xd = nc.createDimension('x',33)
+        yd = nc.createDimension('y',4)
+        v = nc.createVariable('v',np.float_,('t','x','y'))
+        nc.close()
+        nc = Dataset(self.file)
+        data = np.empty(nc['v'].shape, nc['v'].dtype)
+        data2 = nc['v'][...]
+        assert_array_equal(data,data2)
+        nc.close()
+
+    def test_issue906(self):
+        f = Dataset(self.file,'w')
+        f.createDimension('d1',3)
+        f.createDimension('d2',None)
+        f.createDimension('d3',5)
+        f.createVariable('v2',np.float_,('d1','d2','d3'))
+        f['v2'][:] = np.zeros((3,4,5))
+        f['v2'][0,:,0] = np.arange(4)
+        f['v2'][0,:,:] = np.ones((4,5))
+        f.close()
+
+    def test_issue919(self):
+        with Dataset(self.file,'w') as f:
+            f.createDimension('time',2)
+            f.createDimension('lat',10)
+            f.createDimension('lon',9)
+            f.createVariable('v1',np.int,('time', 'lon','lat',))
+            arr = np.arange(9*10).reshape((9, 10))
+            f['v1'][:] = arr
+            assert_array_equal(f['v1'][:],np.broadcast_to(arr,f['v1'].shape))
+            arr = np.arange(10)
+            f['v1'][:] = arr
+            assert_array_equal(f['v1'][:],np.broadcast_to(arr,f['v1'].shape))
+
+    def test_issue922(self):
+        with Dataset(self.file,'w') as f:
+            f.createDimension('d1',3)
+            f.createDimension('d2',None)
+            f.createVariable('v1',np.int,('d2','d1',))
+            f['v1'][0] = np.arange(3,dtype=np.int)
+            f['v1'][1:3] = np.arange(3,dtype=np.int)
+            assert_array_equal(f['v1'][:], np.broadcast_to(np.arange(3),(3,3)))
+            f.createVariable('v2',np.int,('d1','d2',))
+            f['v2'][:,0] = np.arange(3,dtype=np.int)
+            f['v2'][:,1:3] = np.arange(6,dtype=np.int).reshape(3,2)
+            assert_array_equal(f['v2'][:,1:3],np.arange(6,dtype=np.int).reshape(3,2))
+            assert_array_equal(f['v2'][:,0],np.arange(3,dtype=np.int))
+
+    def test_issue1083(self):
+        with Dataset(self.file, "w") as nc:
+            nc.createDimension("test", 5)
+            v = nc.createVariable("var", "f8", ("test", "test", "test"))
+            v[:] = 1 # works
+            v[:] = np.ones(()) # works
+            v[:] = np.ones((1,)) # works
+            v[:] = np.ones((5,)) # works
+            v[:] = np.ones((5,5,5)) # works
+            v[:] = np.ones((5,1,1)) # fails (before PR #1084)
+            v[:] = np.ones((5,1,5)) # fails (before PR #1084)
+            v[:] = np.ones((5,5,1)) # fails (before PR #1084)
+
 if __name__ == '__main__':
     unittest.main()
